===============================
suitcase
===============================

.. image:: https://img.shields.io/travis/NSLS-II/suitcase.svg
        :target: https://travis-ci.org/NSLS-II/suitcase

.. image:: https://img.shields.io/pypi/v/suitcase.svg
        :target: https://pypi.python.org/pypi/suitcase


Exporters / serializers for bluesky documents.

* Free software: 3-clause BSD license
* Documentation: (COMING SOON!) https://NSLS-II.github.io/suitcase.

Features
--------

* TODO
